==> shiny.fluent_0.3.0.tar.gz: shiny.fluent/R/examples.R <==
# All files from `inst/examples` in alphabetical order.

#' @example inst/examples/ActivityItem.R
#' @name ActivityItem
NULL

#' @example inst/examples/Announced.R
#' @name Announced
NULL

#' @example inst/examples/Breadcrumb.R
#' @name Breadcrumb
NULL

#' @example inst/examples/Button.R
#' @name Button
NULL

#' @example inst/examples/Calendar.R
#' @name Calendar
NULL

#' @example inst/examples/Callout.R
#' @name Callout
NULL

#' @example inst/examples/Checkbox.R
#' @name Checkbox
NULL

#' @example inst/examples/ChoiceGroup.R
#' @name ChoiceGroup
NULL

#' @example inst/examples/Coachmark.R
#' @name Coachmark
NULL

#' @example inst/examples/ColorPicker.R
#' @name ColorPicker
NULL

#' @example inst/examples/ComboBox.R
#' @name ComboBox
NULL

#' @example inst/examples/CommandBar.R
#' @name CommandBar
NULL

#' @example inst/examples/ContextualMenu.R
#' @name ContextualMenu
NULL

#' @example inst/examples/DatePicker.R
#' @name DatePicker
NULL

#' @example inst/examples/DetailsList.R
#' @name DetailsList
NULL

#' @example inst/examples/Dialog.R
#' @name Dialog
NULL

#' @example inst/examples/DocumentCard.R
#' @name DocumentCard
NULL

#' @example inst/examples/Dropdown.R
#' @name Dropdown
NULL

#' @example inst/examples/Facepile.R
#' @name Facepile
NULL

#' @example inst/examples/FocusTrapZone.R
#' @name FocusTrapZone
NULL

#' @example inst/examples/FocusZone.R
#' @name FocusZone
NULL

#' @example inst/examples/GroupedList.R
#' @name GroupedList
NULL

#' @example inst/examples/HoverCard.R
#' @name HoverCard
NULL

#' @example inst/examples/Icon.R
#' @name Icon
NULL

#' @example inst/examples/Image.R
#' @name Image
NULL

#' @example inst/examples/Keytips.R
#' @name Keytips
NULL

#' @example inst/examples/Label.R
#' @name Label
NULL

#' @example inst/examples/Layer.R
#' @name Layer
NULL

#' @example inst/examples/LayerHost.R
#' @name Layer
NULL

#' @example inst/examples/Link.R
#' @name Link
NULL

#' @example inst/examples/List.R
#' @name List
NULL

#' @example inst/examples/MarqueeSelection.R
#' @name MarqueeSelection
NULL

#' @example inst/examples/MessageBar.R
#' @name MessageBar
NULL

#' @example inst/examples/Modal.R
#' @name Modal
NULL

#' @example inst/examples/Nav.R
#' @name Nav
NULL

#' @example inst/examples/OverflowSet.R
#' @name OverflowSet
NULL

#' @example inst/examples/Overlay.R
#' @name Overlay
NULL

#' @example inst/examples/Panel.R
#' @name Panel
NULL

#' @example inst/examples/PeoplePicker.R
#' @name PeoplePicker
NULL

#' @example inst/examples/Persona.R
#' @name Persona
NULL

#' @example inst/examples/Pivot.R
#' @name Pivot
NULL

#' @example inst/examples/ProgressIndicator.R
#' @name ProgressIndicator
NULL

#' @example inst/examples/Rating.R
#' @name Rating
NULL

#' @example inst/examples/ResizeGroup.R
#' @name ResizeGroup
NULL

#' @example inst/examples/ScrollablePane.R
#' @name ScrollablePane
NULL

#' @example inst/examples/SearchBox.R
#' @name SearchBox
NULL

#' @example inst/examples/Separator.R
#' @name Separator
NULL

#' @example inst/examples/Shimmer.R
#' @name Shimmer
NULL

#' @example inst/examples/Slider.R
#' @name Slider
NULL

#' @example inst/examples/SpinButton.R
#' @name SpinButton
NULL

#' @example inst/examples/Spinner.R
#' @name Spinner
NULL

#' @example inst/examples/Stack.R
#' @name Stack
NULL

#' @example inst/examples/SwatchColorPicker.R
#' @name SwatchColorPicker
NULL

#' @example inst/examples/TagPicker.R
#' @name Pickers
NULL

#' @example inst/examples/TeachingBubble.R
#' @name TeachingBubble
NULL

#' @example inst/examples/Text.R
#' @name Text
NULL

#' @example inst/examples/TextField.R
#' @name TextField
NULL

#' Fluent UI themes
#'
#' Themes is not a component, but a way to override the default theme in the app.
#' See https://developer.microsoft.com/en-us/fluentui#/controls/web/themes for details.
#'
#' @example inst/examples/Theme.R
#' @name Theme
NULL

#' @example inst/examples/Toggle.R
#' @name Toggle
NULL

#' @example inst/examples/Tooltip.R
#' @name Tooltip
NULL

==> shiny.fluent_0.4.0.tar.gz: shiny.fluent/R/examples.R <==
# All files from `inst/examples` in alphabetical order.

#' @example inst/examples/ActivityItem.R
#' @name ActivityItem
NULL

#' @example inst/examples/Announced.R
#' @name Announced
NULL

#' @example inst/examples/Breadcrumb.R
#' @name Breadcrumb
NULL

#' @example inst/examples/Button.R
#' @example inst/examples/Button2.R
#' @example inst/examples/Button3.R
#' @example inst/examples/Button4.R
#' @name Button
NULL

#' @example inst/examples/Calendar.R
#' @name Calendar
NULL

#' @example inst/examples/Callout.R
#' @name Callout
NULL

#' @example inst/examples/Checkbox.R
#' @name Checkbox
NULL

#' @example inst/examples/ChoiceGroup.R
#' @name ChoiceGroup
NULL

#' @example inst/examples/Coachmark.R
#' @name Coachmark
NULL

#' @example inst/examples/ColorPicker.R
#' @name ColorPicker
NULL

#' @example inst/examples/ComboBox.R
#' @name ComboBox
NULL

#' @example inst/examples/CommandBar.R
#' @name CommandBar
NULL

#' @example inst/examples/ContextualMenu.R
#' @name ContextualMenu
NULL

#' @example inst/examples/DatePicker.R
#' @example inst/examples/DatePicker2.R
#' @name DatePicker
NULL

#' @example inst/examples/DetailsList.R
#' @example inst/examples/DetailsList2.R
#' @example inst/examples/DetailsList3.R
#' @name DetailsList
NULL

#' @example inst/examples/Dialog.R
#' @name Dialog
NULL

#' @example inst/examples/DocumentCard.R
#' @example inst/examples/DocumentCard2.R
#' @name DocumentCard
NULL

#' @example inst/examples/Dropdown.R
#' @example inst/examples/Dropdown2.R
#' @name Dropdown
NULL

#' @example inst/examples/Facepile.R
#' @name Facepile
NULL

#' @example inst/examples/FocusTrapZone.R
#' @name FocusTrapZone
NULL

#' @example inst/examples/FocusZone.R
#' @name FocusZone
NULL

#' @example inst/examples/GroupedList.R
#' @example inst/examples/GroupedList2.R
#' @name GroupedList
NULL

#' @example inst/examples/HoverCard.R
#' @name HoverCard
NULL

#' @example inst/examples/Icon.R
#' @name Icon
NULL

#' @example inst/examples/Image.R
#' @name Image
NULL

#' @example inst/examples/Keytips.R
#' @name Keytips
NULL

#' @example inst/examples/Label.R
#' @name Label
NULL

#' @example inst/examples/Layer.R
#' @name Layer
NULL

#' @example inst/examples/LayerHost.R
#' @name Layer
NULL

#' @example inst/examples/Link.R
#' @name Link
NULL

#' @example inst/examples/List.R
#' @name List
NULL

#' @example inst/examples/MarqueeSelection.R
#' @name MarqueeSelection
NULL

#' @example inst/examples/MessageBar.R
#' @name MessageBar
NULL

#' @example inst/examples/Modal.R
#' @name Modal
NULL

#' @example inst/examples/Nav.R
#' @example inst/examples/Nav2.R
#' @name Nav
NULL

#' @example inst/examples/OverflowSet.R
#' @name OverflowSet
NULL

#' @example inst/examples/Overlay.R
#' @name Overlay
NULL

#' @example inst/examples/Panel.R
#' @name Panel
NULL

#' @example inst/examples/PeoplePicker.R
#' @name PeoplePicker
NULL

#' @example inst/examples/Persona.R
#' @name Persona
NULL

#' @example inst/examples/Pivot.R
#' @name Pivot
NULL

#' @example inst/examples/ProgressIndicator.R
#' @name ProgressIndicator
NULL

#' @example inst/examples/Rating.R
#' @name Rating
NULL

#' @example inst/examples/ResizeGroup.R
#' @name ResizeGroup
NULL

#' @example inst/examples/ScrollablePane.R
#' @name ScrollablePane
NULL

#' @example inst/examples/SearchBox.R
#' @name SearchBox
NULL

#' @example inst/examples/Separator.R
#' @name Separator
NULL

#' @example inst/examples/Shimmer.R
#' @name Shimmer
NULL

#' @example inst/examples/Slider.R
#' @name Slider
NULL

#' @example inst/examples/SpinButton.R
#' @name SpinButton
NULL

#' @example inst/examples/Spinner.R
#' @name Spinner
NULL

#' @example inst/examples/Stack.R
#' @name Stack
NULL

#' @example inst/examples/SwatchColorPicker.R
#' @name SwatchColorPicker
NULL

#' @example inst/examples/TagPicker.R
#' @name Pickers
NULL

#' @example inst/examples/TeachingBubble.R
#' @name TeachingBubble
NULL

#' @example inst/examples/Text.R
#' @name Text
NULL

#' @example inst/examples/TextField.R
#' @example inst/examples/TextField2.R
#' @name TextField
NULL

#' Fluent UI themes
#'
#' `ThemeProvider` is a utility that applies contextual theming to its child components.
#' See the [official docs](https://developer.microsoft.com/en-us/fluentui#/controls/web/themeprovider)
#' for details.
#'
#' @example inst/examples/ThemeProvider.R
#' @example inst/examples/ThemeProvider2.R
#' @name Theme
NULL

#' @example inst/examples/Toggle.R
#' @name Toggle
NULL

#' @example inst/examples/Tooltip.R
#' @name Tooltip
NULL
